@@ -93,8 +93,8 @@ image_task_completed_cb (GthTask  *task,
 
 	if (self->priv->apply_to_original) {
 		if (self->priv->destination != NULL) {
-			GtkWidget *window;
-			GtkWidget *viewer_page;
+			GtkWidget     *window;
+			GthViewerPage *viewer_page;
 
 			window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 			viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
@@ -202,7 +202,7 @@ gth_file_tool_effects_get_options (GthFileTool *base)
 {
 	GthFileToolEffects *self;
 	GtkWidget          *window;
-	GtkWidget          *viewer_page;
+	GthViewerPage      *viewer_page;
 	GtkWidget          *viewer;
 	cairo_surface_t    *source;
 	GtkWidget          *options;
@@ -264,7 +264,7 @@ gth_file_tool_effects_destroy_options (GthFileTool *base)
 {
 	GthFileToolEffects *self;
 	GtkWidget          *window;
-	GtkWidget          *viewer_page;
+	GthViewerPage      *viewer_page;
 
 	self = (GthFileToolEffects *) base;
 
@@ -276,7 +276,7 @@ gth_file_tool_effects_destroy_options (GthFileTool *base)
 	window = gth_file_tool_get_window (GTH_FILE_TOOL (self));
 	viewer_page = gth_browser_get_viewer_page (GTH_BROWSER (window));
 	gth_image_viewer_page_reset_viewer_tool (GTH_IMAGE_VIEWER_PAGE (viewer_page));
-	gth_viewer_page_update_sensitivity (GTH_VIEWER_PAGE (viewer_page));
+	gth_viewer_page_update_sensitivity (viewer_page);
 
 	_g_clear_object (&self->priv->builder);
 
@@ -369,7 +369,6 @@ warmer_exec (GthAsyncTask *task,
 	cairo_surface_t *original;
 	cairo_surface_t *source;
 	GthCurve	*curve[GTH_HISTOGRAM_N_CHANNELS];
-	gboolean         cancelled = FALSE;
 
 	original = gth_image_task_get_source_surface (GTH_IMAGE_TASK (task));
 	source = _cairo_image_surface_copy (original);
@@ -414,7 +413,6 @@ cooler_exec (GthAsyncTask *task,
 	cairo_surface_t *original;
 	cairo_surface_t *source;
 	GthCurve	*curve[GTH_HISTOGRAM_N_CHANNELS];
-	gboolean         cancelled = FALSE;
 
 	original = gth_image_task_get_source_surface (GTH_IMAGE_TASK (task));
 	source = _cairo_image_surface_copy (original);
@@ -589,7 +587,7 @@ artic_add_to_special_effects (GthFilterGrid *grid)
 				    GTH_FILTER_GRID_NEW_FILTER_ID,
 				    gth_image_task_new (_("Applying changes"), NULL, artic_exec, NULL, NULL, NULL),
 				    /* Translators: this is the name of an image filter */
-				    _("Artic"),
+				    _("Arctic"),
 				    NULL);
 }
 
@@ -700,7 +698,6 @@ cherry_exec (GthAsyncTask *task,
 	cairo_surface_t *original;
 	cairo_surface_t *source;
 	GthCurve	*curve[GTH_HISTOGRAM_N_CHANNELS];
-	gboolean         cancelled = FALSE;
 
 	original = gth_image_task_get_source_surface (GTH_IMAGE_TASK (task));
 	source = _cairo_image_surface_copy (original);
@@ -748,7 +745,6 @@ vintage_exec (GthAsyncTask *task,
 	cairo_surface_t *original;
 	cairo_surface_t *source;
 	GthCurve	*curve[GTH_HISTOGRAM_N_CHANNELS];
-	gboolean         cancelled = FALSE;
 
 	original = gth_image_task_get_source_surface (GTH_IMAGE_TASK (task));
 	source = _cairo_image_surface_copy (original);
@@ -919,7 +915,6 @@ vignette_exec (GthAsyncTask *task,
 {
 	cairo_surface_t *original;
 	cairo_surface_t *destination;
-	gboolean         cancelled = FALSE;
 
 	original = gth_image_task_get_source_surface (GTH_IMAGE_TASK (task));
 	destination = _cairo_image_surface_copy (original);
