@@ -194,8 +194,6 @@ gth_browser_activate_browser_mode (GSimpleAction *action,
 	viewer_sidebar = gth_browser_get_viewer_sidebar (browser);
 	if (gth_sidebar_tool_is_active (GTH_SIDEBAR (viewer_sidebar)))
 		gth_sidebar_deactivate_tool (GTH_SIDEBAR (viewer_sidebar));
-	else if (gth_browser_get_is_fullscreen (browser))
-		gth_browser_unfullscreen (browser);
 	else
 		gth_window_set_current_page (GTH_WINDOW (browser), GTH_BROWSER_PAGE_BROWSER);
 }
@@ -336,14 +334,14 @@ gth_browser_activate_revert_to_saved (GSimpleAction *action,
 				      GVariant      *parameter,
 				      gpointer       user_data)
 {
-	GthBrowser *browser = user_data;
-	GtkWidget  *viewer_page;
+	GthBrowser    *browser = user_data;
+	GthViewerPage *viewer_page;
 
 	viewer_page = gth_browser_get_viewer_page (browser);
 	if (viewer_page == NULL)
 		return;
 
-	gth_viewer_page_revert (GTH_VIEWER_PAGE (viewer_page));
+	gth_viewer_page_revert (viewer_page);
 }
 
 
@@ -352,14 +350,14 @@ gth_browser_activate_save (GSimpleAction *action,
 			   GVariant      *parameter,
 			   gpointer       user_data)
 {
-	GthBrowser *browser = user_data;
-	GtkWidget  *viewer_page;
+	GthBrowser    *browser = user_data;
+	GthViewerPage *viewer_page;
 
 	viewer_page = gth_browser_get_viewer_page (browser);
 	if (viewer_page == NULL)
 		return;
 
-	gth_viewer_page_save (GTH_VIEWER_PAGE (viewer_page), NULL, NULL, browser);
+	gth_viewer_page_save (viewer_page, NULL, NULL, browser);
 }
 
 
@@ -368,14 +366,14 @@ gth_browser_activate_save_as (GSimpleAction *action,
 			      GVariant      *parameter,
 			      gpointer       user_data)
 {
-	GthBrowser *browser = user_data;
-	GtkWidget  *viewer_page;
+	GthBrowser    *browser = user_data;
+	GthViewerPage *viewer_page;
 
 	viewer_page = gth_browser_get_viewer_page (browser);
 	if (viewer_page == NULL)
 		return;
 
-	gth_viewer_page_save_as (GTH_VIEWER_PAGE (viewer_page), NULL, NULL);
+	gth_viewer_page_save_as (viewer_page, NULL, NULL);
 }
 
 
