@@ -37,6 +37,9 @@ G_BEGIN_DECLS
 #define GTH_BROWSER_MENU_MANAGER_GEARS				"gears"
 #define GTH_BROWSER_MENU_MANAGER_GEARS_FOLDER_ACTIONS		"gears.folder-actions"
 #define GTH_BROWSER_MENU_MANAGER_GEARS_OTHER_ACTIONS		"gears.other-actions"
+#define GTH_BROWSER_MENU_MANAGER_GEARS_PREFERENCES_ACTIONS	"gears.preferences-actions"
+#define GTH_BROWSER_MENU_MANAGER_GEARS_HELP_ACTIONS		"gears.help-actions"
+#define GTH_BROWSER_MENU_MANAGER_GEARS_CLOSE_ACTIONS		"gears.close-actions"
 #define GTH_BROWSER_MENU_MANAGER_FILE				"file"
 #define GTH_BROWSER_MENU_MANAGER_FILE_SCREEN_ACTIONS		"file.screen-actions"
 #define GTH_BROWSER_MENU_MANAGER_FILE_OPEN_ACTIONS		"file.open-actions"
